/************************************************************************/
/*																		*/
/*	CDC1.cpp		--		Definition for CDC1 library 	   			*/
/*																		*/
/************************************************************************/
/*	Author:		Eric Marsh												*/
/*	Copyright 2016, Digilent Inc.										*/
/************************************************************************/
/*  File Description:													*/
/*		This file defines functions for the PmodCDC1					*/
/*																		*/
/************************************************************************/
/*  Revision History:													*/
/*																		*/
/*	08/3/2016(EricM): created											*/
/*																		*/
/************************************************************************/


/* ------------------------------------------------------------ */
/*				Include File Definitions						*/
/* ------------------------------------------------------------ */
#include "CDC1.h"
#include <WProgram.h>

/* ------------------------------------------------------------ */
/*				Procedure Definitions							*/
/* ------------------------------------------------------------ */

/* ------------------------------------------------------------ */
/*        CDC1::CDC1
**
**        Synopsis:
**				
**        Parameters:
**
**
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**			Class constructor. Performs variables initialization tasks
**
**
*/
CDC1::CDC1()
{
	btn1_pin = -1;
	btn2_pin = -1;
}

/* ------------------------------------------------------------ */
/*        CDC1::begin
**
**        Synopsis:
**				myCDC1.begin(10, 11);
**        Parameters:
**				int pin1 - Pin for BTN1. -1 by default
**				int pin2 - Pin for BTN2. -1 by default
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**				This function initializes the BTN pins.
**
*/
void CDC1::begin(int pin1, int pin2)
{
	btn1_pin = pin1;
	btn2_pin = pin2;
	
	pinMode(btn1_pin, INPUT);
	pinMode(btn2_pin, INPUT);
}

/* ------------------------------------------------------------ */
/*        CDC1::GetStatus
**
**        Synopsis:
**				myCDC1.GetStatus(1);
**        Parameters:
**				int btn - The number of the btn to get the status of (1 or 2)
**
**        Return Values:
**                void 
**
**        Errors:
**
**
**        Description:
**				Checks the status of the button.
**
*/
bool CDC1::GetStatus(int btn)
{
	if(btn == 1){
		if(btn1_pin != -1){
			return digitalRead(btn1_pin);
		}else{
			return false;
		}
	}
	if(btn == 2){
		if(btn2_pin != -1){
			return digitalRead(btn2_pin);
		}else{
			return false;	
		}
	}
}