/************************************************************************/
/*				        	                        */
/*	  PmodCDC1 Demo Project 		                        */
/*					    	                        */
/************************************************************************/
/*	Author: Eric Marsh					        */
/*	Copyright 2016, Digilent Inc.					*/
/************************************************************************/
/*  File Description: 			             		        */
/*					                        	*/
/* This file implements a simple demo application that demonstrates     */
/* how to setup and use the PmodCDC1.				        */
/*									*/
/*	Functionality:							*/
/*									*/
/* In the setup() function, the PmodCDC1 is initialized through         */
/* calling the ALS library.                                             */
/*                                                                      */
/*                                                                      */
/* In the loop() function, the application repeatedly checks the        */
/* sensor status of the PmodCDC1 and prints out the result.             */
/*					       	                        */
/* This demo was tested with chipKit UC32, with pins 10 and 11          */
/*					       	                        */					       	             
/*	Required Hardware:		                                */
/*	  1. PIC32 based Microcontroller    	                        */
/*	  2. PmodCDC1                                           	*/
/*			                                                */
/************************************************************************/
/*  Revision History:			        			*/
/*					                        	*/
/*	08/3/2016(EricM): Created	       			        */
/*                                                                      */
/*					      	                        */
/************************************************************************/

/* -------------------------------------------------------------------- */
/*		        Include File Definitions                     	*/
/* -------------------------------------------------------------------- */
#include <CDC1.h>
#include <WProgram.h>

/* -------------------------------------------------------------------- */
/*		            Global Variables                     	*/
/* -------------------------------------------------------------------- */
// JE port pins on the chipKIT mx3ck
int pinBtn1 = 32;
int pinBtn2 = 33;

CDC1 myCDC1;

void setup()
{
  // Initialize serial monitor
  Serial.begin(9600);
  
  // Initialize PmodCDC1, passing the output pins for BTN1 and BTN2.
  myCDC1.begin(pinBtn1, pinBtn2);
}

void loop()
{
  // Check status of BTN1
  if(myCDC1.GetStatus(1)){
    Serial.print("1");
  }
  
  // Check status of BTN2
  if(myCDC1.GetStatus(2)){
    Serial.print("  2");
  }
  
  // Syntax reasons
  if(myCDC1.GetStatus(1) || myCDC1.GetStatus(2)){
    Serial.print("\n");
  }
  
  // Delay for fun
  delay(100);
}